==> ejc-sddjsorg-impl-3.0.0-20211025.064720-62-sources.jar: com/ejianc/business/orgcenter/bean/AdministrativeAreaEntity.java <==
package com.ejianc.business.orgcenter.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 行政地区实体
 *
 * @author CJ
 * @Description:
 * @date 2021/10/12 10:23
 */
@TableName(value = "ejc_sddjsorg_administrative_area")
public class AdministrativeAreaEntity extends BaseEntity {

    private static final long serialVersionUID = 5256244655288009725L;

    /**
     * 行政地区编码
     */
    @TableField(value = "bill_code")
    private String BillCode;

    /**
     * 行政地区名称
     */
    @TableField(value = "area_name")
    private String areaName;

    /**
     * 状态：0-停用，1-启用
     */
    @TableField(value = "status")
    private Integer status;

    /**
     * 行政地区登记
     */
    @TableField(value = "level")
    private Integer level;

    /**
     * 上级行政地区Id
     */
    @TableField(value = "pid")
    private Long pid;

    /**
     * 上级行政地区名称
     */
    @TableField(value = "p_name")
    private String pName;

    /**
     * 描述
     */
    @TableField(value = "description")
    private String description;

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getBillCode() {
        return BillCode;
    }

    public void setBillCode(String billCode) {
        BillCode = billCode;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getLevel() {
        return level;
    }

    public void setLevel(Integer level) {
        this.level = level;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getpName() {
        return pName;
    }

    public void setpName(String pName) {
        this.pName = pName;
    }
}

==> ejc-sddjsorg-impl-3.0.0-20211104.063347-142-sources.jar: com/ejianc/business/orgcenter/bean/AdministrativeAreaEntity.java <==
package com.ejianc.business.orgcenter.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 行政地区实体
 *
 * @author CJ
 * @Description:
 * @date 2021/10/12 10:23
 */
@TableName(value = "ejc_sddjsorg_administrative_area")
public class AdministrativeAreaEntity extends BaseEntity {

    private static final long serialVersionUID = 5256244655288009725L;

    /**
     * 行政地区编码
     */
    @TableField(value = "bill_code")
    private String BillCode;

    /**
     * 行政地区名称
     */
    @TableField(value = "area_name")
    private String areaName;

    /**
     * 状态：0-停用，1-启用
     */
    @TableField(value = "status")
    private Integer status;

    /**
     * 行政地区登记
     */
    @TableField(value = "level")
    private Integer level;

    /**
     * 上级行政地区Id
     */
    @TableField(value = "pid")
    private Long pid;

    /**
     * 上级行政地区名称
     */
    @TableField(value = "p_name")
    private String pName;

    /**
     * 描述
     */
    @TableField(value = "description")
    private String description;

    /**
     * 内码
     */
    @TableField(value = "inner_code")
    private String innerCode;

    public String getInnerCode() {
        return innerCode;
    }

    public void setInnerCode(String innerCode) {
        this.innerCode = innerCode;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getBillCode() {
        return BillCode;
    }

    public void setBillCode(String billCode) {
        BillCode = billCode;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getLevel() {
        return level;
    }

    public void setLevel(Integer level) {
        this.level = level;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getpName() {
        return pName;
    }

    public void setpName(String pName) {
        this.pName = pName;
    }
}
